Changelog
=========
0.2.0
~~~~~

- Fix CI process
- Add tests to increase the coverage
- Fix read me file

0.1.3
~~~~~

- Add ClientAPIAuthenticatedDeleteView and ClientAPIDeleteView
- BugFix: Use the correct constant to defaults (DEFAULTS) and the api (API_DEFAULTS)

0.1.2
~~~~~

- Add documentation and fix Python version


0.1.1
~~~~~

- Remove python 3.8 from setup because pypi dont support yet

0.1.0
~~~~~

- Initial release
